@@ -7,7 +7,7 @@ from collections.abc import Mapping
 from http import HTTPStatus
 from http.cookies import SimpleCookie
 from json import JSONDecodeError
-from typing import AnyStr, Optional, TypeVar, Union
+from typing import AnyStr, Optional, Union
 from urllib.parse import quote_plus
 
 import addict
@@ -20,7 +20,7 @@ from urllib3.filepost import RequestField, encode_multipart_formdata
 
 from ._utils import _AppRef
 
-T = TypeVar("T")
+
 Headers = Union[Mapping[str, str], list[tuple[str, str]]]
 Params = Union[Mapping[str, str], list[tuple[str, str]]]
 
